﻿using System.Collections.Generic;
using TSLab.Script;
using TSLab.Script.Handlers;

namespace Урок_7._3
{
    /// <summary>
    /// Вспомогательный класс, содержащий хелпер методы. В том числе и методы расширения.
    /// </summary>
    public static class TradeHelper
    {
        /// <summary>
        /// Производит вычитание двух коллекций. 
        /// Из первой вычитает вторую и возвращает коллекцию с элементами равными разности элементов коллекций 1 и 2.
        /// Если колллекции разной длины, то вернет null.
        /// </summary>
        /// <param name="list">Коллекция из которой вычитать</param>
        /// <param name="subtrList">Колллекция которую будет вычитать.</param>
        /// <returns></returns>
        public static IList<double> Subtract(this IList<double> list, IList<double> subtrList)
        {
            // Если длины коллекций различаются то просто вернем null как знак ошибки.
            if (list.Count != subtrList.Count)
                return null;

            // Создаем массив, и забиваем его разностями элементов списков.
            var res = new double[list.Count];
            for (var i = 0; i < list.Count; i++)
                res[i] = list[i] - subtrList[i];


            return res;
        }

        /// <summary>
        /// Производит вычитание двух коллекций. 
        /// Из первой вычитает вторую и возвращает коллекцию с элементами равными разности элементов коллекций 1 и 2.
        /// Если колллекции разной длины, то вернет null.
        /// </summary>
        /// <param name="list">Коллекция из которой вычитать</param>
        /// <param name="subtrList">Колллекция которую будет вычитать.</param>
        /// <returns></returns>
        public static IList<int> Subtract(this IList<int> list, IList<int> subtrList)
        {
            // Если длины коллекций различаются то просто вернем null как знак ошибки.
            if (list.Count != subtrList.Count)
                return null;

            // Создаем массив, и забиваем его разностями элементов списков.
            var res = new int[list.Count];
            for (var i = 0; i < list.Count; i++)
                res[i] = list[i] - subtrList[i];


            return res;
        }

        /// <summary>
        /// Производит сложение двух коллекций. 
        /// К первой коллекции прибавляет вторую и возвращает коллекцию с элементами равными сумме элементов коллекций 1 и 2.
        /// Если колллекции разной длины, то вернет null.
        /// </summary>
        /// <param name="list">Коллекция к которой прибавлять</param>
        /// <param name="subtrList">Колллекция которую будем прибавлять.</param>
        /// <returns></returns>
        public static IList<double> Add(this IList<double> list, IList<double> subtrList)
        {
            // Если длины коллекций различаются то просто вернем null как знак ошибки.
            if (list.Count != subtrList.Count)
                return null;

            // Создаем массив, и забиваем его суммами элементов списков.
            var res = new double[list.Count];
            for (var i = 0; i < list.Count; i++)
                res[i] = list[i] + subtrList[i];


            return res;
        }

        /// <summary>
        /// Производит сложение двух коллекций. 
        /// К первой коллекции прибавляет вторую и возвращает коллекцию с элементами равными сумме элементов коллекций 1 и 2.
        /// Если колллекции разной длины, то вернет null.
        /// </summary>
        /// <param name="list">Коллекция к которой прибавлять</param>
        /// <param name="subtrList">Колллекция которую будем прибавлять.</param>
        /// <returns></returns>
        public static IList<int> Add(this IList<int> list, IList<int> subtrList)
        {
            // Если длины коллекций различаются то просто вернем null как знак ошибки.
            if (list.Count != subtrList.Count)
                return null;

            // Создаем массив, и забиваем его суммами элементов списков.
            var res = new int[list.Count];
            for (var i = 0; i < list.Count; i++)
                res[i] = list[i] + subtrList[i];

            return res;
        }

        /// <summary>
        /// Выводит в лог информационное сообщение.
        /// </summary>
        /// <param name="ctx"></param>
        /// <param name="str"></param>
        public static void LogInfo(this IContext ctx, string str)
        {
            // Задаем цвет соообщения
            var color = new Color(System.Drawing.Color.Blue.ToArgb());

            ctx.Log(str, color);
        }
    }
}
